testdoc ⸺ testdoc

Skip to main content

## Metrics as Proxies

A metric is a proxy. A stand-in, something meant to represent something else. This is forgotten by many people. When that marketing team chose a metric of high blog hit counts, they were originally trying to ensure we had blog content that was interesting to a large number of developers, our product (and therefore sales and therefore revenue) audience. The proxy for being interesting to our audience was how many people visited the blog posts. A stand-in, something meant to represent something else.